aboutsummaryrefslogtreecommitdiff
path: root/shared-core/i915_drm.h
diff options
context:
space:
mode:
authorDave Airlie <airlied@redhat.com>2008-01-24 14:37:40 +1000
committerDave Airlie <airlied@redhat.com>2008-01-24 14:37:40 +1000
commit34b71eb45124b32377b82b4d3737537b9195b0a7 (patch)
tree9371b28775e35eef7a2ad140056ba211ed8f74eb /shared-core/i915_drm.h
parentb5a34f5da50e22ecb80853f0f422beb90857dc2d (diff)
i915 make relocs use copy from user
Switch relocs to using copy from user and remove index and pass buffer handles in instead.
Diffstat (limited to 'shared-core/i915_drm.h')
-rw-r--r--shared-core/i915_drm.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/shared-core/i915_drm.h b/shared-core/i915_drm.h
index cfa3f93a..c8a9cb76 100644
--- a/shared-core/i915_drm.h
+++ b/shared-core/i915_drm.h
@@ -329,9 +329,9 @@ typedef struct drm_i915_hws_addr {
/*
* Relocation header is 4 uint32_ts
* 0 - (16-bit relocation type << 16)| 16 bit reloc count
* 1 - buffer handle for another list of relocs
* 2-3 - spare.
*/
#define I915_RELOC_HEADER 4
@@ -339,7 +339,7 @@ typedef struct drm_i915_hws_addr {
* type 0 relocation has 4-uint32_t stride
* 0 - offset into buffer
* 1 - delta to add in
- * 2 - index into buffer list
+ * 2 - buffer handle
* 3 - reserved (for optimisations later).
*/
#define I915_RELOC_TYPE_0 0
@@ -347,7 +347,7 @@ typedef struct drm_i915_hws_addr {
struct drm_i915_op_arg {
uint64_t next;
- uint32_t reloc_handle;
+ uint64_t reloc_ptr;
int handled;
union {
struct drm_bo_op_req req;
@@ -329,9 +329,9 @@ typedef struct drm_i915_hws_addr {
/*
* Relocation header is 4 uint32_ts
- * 0 - (16-bit relocation type << 16)| 16 bit reloc count
- * 1 - buffer handle for another list of relocs
- * 2-3 - spare.
+ * 0 - 32 bit reloc count
+ * 1 - 32-bit relocation type
+ * 2-3 - 64-bit user buffer handle ptr for another list of relocs.
*/
#define I915_RELOC_HEADER 4